@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006,2007,2011 Guido Günther <agx@sigxcpu.org>
+# (C) 2006,2007,2011,2017 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -27,6 +27,7 @@ from gbp.git import GitRepositoryError
 from gbp.deb.changelog import ChangeLog, NoChangeLogError
 from gbp.deb.policy import DebianPkgPolicy
 
+
 class DpkgCompareVersions(gbpc.Command):
     dpkg = '/usr/bin/dpkg'
 
@@ -43,16 +44,16 @@ class DpkgCompareVersions(gbpc.Command):
         @raises CommandExecFailed: if the version comparison fails
         """
         self.run_error = "Couldn't compare %s with %s" % (version1, version2)
-        res = self.call([ version1, 'lt', version2 ])
-        if res not in [ 0, 1 ]:
+        res = self.call([version1, 'lt', version2])
+        if res not in [0, 1]:
             if self.stderr:
                 self.run_error += ' (%s)' % self.stderr
             raise gbpc.CommandExecFailed("%s: bad return code %d" % (self.run_error, res))
         if res == 0:
             return -1
         elif res == 1:
-            res = self.call([ version1, 'gt', version2 ])
-            if res not in [ 0, 1 ]:
+            res = self.call([version1, 'gt', version2])
+            if res not in [0, 1]:
                 if self.stderr:
                     self.run_error += ' (%s)' % self.stderr
                 raise gbpc.CommandExecFailed("%s: bad return code %d" % (self.run_error, res))
@@ -80,21 +81,14 @@ def parse_changelog_repo(repo, branch, filename):
     return ChangeLog(repo.show(sha))
 
 
-def orig_file(cp, compression, subtarball=None):
+def orig_file(source, compression, component=None):
     """
-    The name of the orig file belonging to changelog cp
-
-    >>> orig_file({'Source': 'foo', 'Upstream-Version': '1.0'}, "bzip2")
-    'foo_1.0.orig.tar.bz2'
-    >>> orig_file({'Source': 'bar', 'Upstream-Version': '0.0~git1234'}, "xz")
-    'bar_0.0~git1234.orig.tar.xz'
-    >>> orig_file({'Source': 'bar', 'Upstream-Version': '0.0~git1234'}, "xz", subtarball="sub1")
-    'bar_0.0~git1234.orig-sub1.tar.xz'
+    The name of the orig file belonging to source package I{source}
     """
-    return DebianPkgPolicy.build_tarball_name(cp['Source'],
-                                              cp['Upstream-Version'],
-                                              compression,
-                                              subtarball=subtarball)
+    return DebianPkgPolicy.build_tarball_name(source.name,
+                                              source.upstream_version,
+                                              compression=compression,
+                                              component=component)
 
 
 def get_arch():
