@@ -239,7 +239,8 @@ class GitRepository(object):
         except Exception as excobj:
             raise GitRepositoryError("Error running git %s: %s" % (command, excobj))
         if ret:
-            raise GitRepositoryError("Error running git %s: %s" % (command, stderr))
+            detail = stderr or stdout
+            raise GitRepositoryError("Error running git %s: %s" % (command, detail))
 
     def _cmd_has_feature(self, command, feature):
         """
@@ -491,6 +492,9 @@ class GitRepository(object):
         """
         self._git_command("merge", ["--abort"])
 
+    def is_in_merge(self):
+        return os.path.exists(os.path.join(self.git_dir, 'MERGE_HEAD'))
+
     def is_fast_forward(self, from_branch, to_branch):
         """
         Check if an update I{from from_branch} to I{to_branch} would be a fast
@@ -1106,6 +1110,13 @@ class GitRepository(object):
             raise KeyError
         return value[0][:-1]  # first line with \n ending removed
 
+    def set_config(self, name, value):
+        """
+        Set a git config value in this repository
+        """
+        args = GitArgs(name, value)
+        self._git_command("config", args.args)
+
     def set_user_name(self, name):
         """
         Sets the full name to use for git commits.
@@ -1420,6 +1431,17 @@ class GitRepository(object):
             return self.strip_sha1(sha1)
         else:
             raise GbpError("Failed to hash %s: %s" % (filename, stderr))
+
+    def rename_file(self, old, new):
+        """
+        Rename file, directory, or symlink
+        """
+        args = GitArgs(old, new)
+        _, stderr, ret = self._git_inout('mv',
+                                         args.args,
+                                         capture_stderr=True)
+        if ret:
+            raise GbpError("Failed to move '%s' to '%s': %s" % (old, new, stderr.rstrip()))
 #}
 
 #{ Comitting
@@ -1739,7 +1761,7 @@ class GitRepository(object):
         self._git_command("apply", args)
 
     def diff(self, obj1, obj2=None, paths=None, stat=False, summary=False,
-             text=False, ignore_submodules=True, abbrev=None):
+             text=False, ignore_submodules=True, abbrev=None, renames=False):
         """
         Diff two git repository objects
 
@@ -1769,6 +1791,10 @@ class GitRepository(object):
         options.add_true(summary, '--summary')
         options.add_true(text, '--text')
         options.add_true(ignore_submodules, '--ignore-submodules=all')
+        if isinstance(renames, bool):
+            options.add('-M' if renames else '--no-renames')
+        else:
+            options.add('-M=%s', renames)
         options.add(obj1)
         options.add_true(obj2, obj2)
         if paths:
