@@ -29,12 +29,13 @@ from gbp.command_wrappers import (Command,
                                   RemoveTree)
 from gbp.config import (GbpOptionParserDebian, GbpOptionGroup)
 from gbp.deb.git import (GitRepositoryError, DebianGitRepository)
-from gbp.deb.source import DebianSource, DebianSourceError
+from gbp.deb.source import DebianSource, DebianSourceError, FileVfs
 from gbp.deb.format import DebianSourceFormat
 from gbp.format import format_str
 from gbp.git.vfs import GitVfs
 from gbp.deb.upstreamsource import DebianUpstreamSource
 from gbp.errors import GbpError
+from gbp.scripts.common.pq import is_pq_branch, pq_branch_base
 import gbp.log
 import gbp.notifications
 from gbp.scripts.common.buildpackage import (index_name, wc_name,
@@ -47,15 +48,15 @@ from gbp.pkg import compressor_opts, compressor_aliases, parse_archive_filename
 
 
 # upstream tarball preparation
-def git_archive(repo, cp, output_dir, treeish, comp_type, comp_level, with_submodules, component=None):
+def git_archive(repo, source, output_dir, treeish, comp_type, comp_level, with_submodules, component=None):
     "create a compressed orig tarball in output_dir using git_archive"
     try:
         comp_opts = compressor_opts[comp_type][0]
     except KeyError:
         raise GbpError("Unsupported compression type '%s'" % comp_type)
 
-    output = os.path.join(output_dir, du.orig_file(cp, comp_type, component=component))
-    prefix = "%s-%s" % (cp['Source'], cp['Upstream-Version'])
+    output = os.path.join(output_dir, du.orig_file(source, comp_type, component=component))
+    prefix = "%s-%s" % (source.name, source.upstream_version)
 
     try:
         if repo.has_submodules() and with_submodules:
@@ -80,19 +81,23 @@ def git_archive(repo, cp, output_dir, treeish, comp_type, comp_level, with_submo
     return True
 
 
-def prepare_upstream_tarball(repo, cp, options, tarball_dir, output_dir):
+def prepare_upstream_tarball(repo, source, options, tarball_dir, output_dir):
     """
-    Make sure we have an upstream tarball. This involves loooking in
+    Make sure we have an upstream tarball. This involves looking in
     tarball_dir, symlinking or building it.
     """
+    if not source.is_native() and not source.upstream_version:
+        raise GbpError("Non-native package '%s' "
+                       "has invalid version '%s'" % (source.name, source.version))
+
     options.comp_type = guess_comp_type(repo,
                                         options.comp_type,
-                                        cp,
+                                        source,
                                         options.tarball_dir)
 
-    orig_files = [du.orig_file(cp, options.comp_type)]
+    orig_files = [du.orig_file(source, options.comp_type)]
     if options.components:
-        orig_files += [du.orig_file(cp, options.comp_type, c) for c in options.components]
+        orig_files += [du.orig_file(source, options.comp_type, c) for c in options.components]
 
     # look in tarball_dir first, if found force a symlink to it
     if options.tarball_dir:
@@ -107,16 +112,16 @@ def prepare_upstream_tarball(repo, cp, options, tarball_dir, output_dir):
         return
     # Create tarball if missing or forced
     if not du.DebianPkgPolicy.has_origs(orig_files, output_dir) or options.force_create:
-        if not pristine_tar_build_orig(repo, cp, output_dir, options):
-            upstream_tree = git_archive_build_orig(repo, cp, output_dir, options)
+        if not pristine_tar_build_orig(repo, source, output_dir, options):
+            upstream_tree = git_archive_build_orig(repo, source, output_dir, options)
             if options.pristine_tar_commit:
-                pristine_tar_commit(repo, cp, options, output_dir, orig_files[0], upstream_tree)
-    pristine_tar_verify_orig(repo, cp, options, output_dir, orig_files)
+                pristine_tar_commit(repo, source, options, output_dir, orig_files[0], upstream_tree)
+    pristine_tar_verify_orig(repo, source, options, output_dir, orig_files)
 
 
-def pristine_tar_commit(repo, cp, options, output_dir, orig_file, upstream_tree):
-    if repo.pristine_tar.has_commit(cp.name,
-                                    cp.upstream_version,
+def pristine_tar_commit(repo, source, options, output_dir, orig_file, upstream_tree):
+    if repo.pristine_tar.has_commit(source.name,
+                                    source.upstream_version,
                                     options.comp_type):
         gbp.log.debug("%s already on pristine tar branch" %
                       orig_file)
@@ -128,7 +133,7 @@ def pristine_tar_commit(repo, cp, options, output_dir, orig_file, upstream_tree)
 
 
 # Functions to handle export-dir
-def write_tree(repo, options):
+def maybe_write_tree(repo, options):
     """
     Write a tree of the index or working copy if necessary
 
@@ -168,7 +173,7 @@ def export_source(repo, tree, source, options, dest_dir, tarball_dir):
         if source.is_native():
             raise GbpError("Cannot overlay Debian native package")
         extract_orig(os.path.join(tarball_dir,
-                                  du.orig_file(source.changelog,
+                                  du.orig_file(source,
                                                options.comp_type)),
                      dest_dir)
 
@@ -216,13 +221,10 @@ def extract_orig(orig_tarball, dest_dir):
 
 def source_vfs(repo, options, tree):
     """Init source package info either from git or from working copy"""
-    # FIXME: just init the correct vfs
+    vfs = GitVfs(repo, tree) if tree else FileVfs('.')
     try:
-        if tree:
-            source = DebianSource(GitVfs(repo, tree))
-        else:
-            source = DebianSource('.')
-            source.is_native()  # check early if this works
+        source = DebianSource(vfs)
+        source.is_native()  # check early if this works
     except Exception as e:
         raise GbpError("Can't determine package type: %s" % e)
     return source
@@ -240,14 +242,33 @@ def prepare_output_dir(dir):
     return output_dir
 
 
-def pristine_tar_prepare_orig_tree(repo, cp, options):
+def clean_working_tree(options, repo):
+    """
+    Clean the working tree.
+
+    :param options: Program run-time options, as an `optparse.OptionContainer`.
+    :param repo: The Git repository, as a `DebianGitRepository`.
+    :raise GbpError: When the working tree has uncommitted changes.
+    :return: None.
+    """
+    Command(options.cleaner, shell=True)()
+    if not options.ignore_new:
+        (ret, out) = repo.is_clean()
+        if not ret:
+            gbp.log.err("You have uncommitted changes in your source tree:")
+            gbp.log.err(out)
+            raise GbpError("Use --git-ignore-new to ignore.")
+
+
+def pristine_tar_prepare_orig_tree(repo, source, options):
     """Make sure the upstream tree exists
     In case of component tarballs we need to recreate a tree for the
     main tarball without the component subdirs.
     """
     if options.components:
         try:
-            upstream_tag = repo.version_to_tag(options.upstream_tag, cp.upstream_version)
+            upstream_tag = repo.version_to_tag(options.upstream_tag,
+                                               source.upstream_version)
             tree_name = "%s^{tree}" % upstream_tag
             repo.tree_drop_dirs(tree_name, options.components)
         except GitRepositoryError:
@@ -255,7 +276,7 @@ def pristine_tar_prepare_orig_tree(repo, cp, options):
                            "orig tarball via pristine-tar" % tree_name)
 
 
-def pristine_tar_build_orig(repo, cp, output_dir, options):
+def pristine_tar_build_orig(repo, source, output_dir, options):
     """
     Build orig tarball using pristine-tar
 
@@ -266,15 +287,15 @@ def pristine_tar_build_orig(repo, cp, output_dir, options):
             gbp.log.warn('Pristine-tar branch "%s" not found' %
                          repo.pristine_tar.branch)
 
-        pristine_tar_prepare_orig_tree(repo, cp, options)
+        pristine_tar_prepare_orig_tree(repo, source, options)
         try:
-            repo.pristine_tar.checkout(cp.name,
-                                       cp.upstream_version,
+            repo.pristine_tar.checkout(source.name,
+                                       source.upstream_version,
                                        options.comp_type,
                                        output_dir)
             for component in options.components:
-                repo.pristine_tar.checkout(cp.name,
-                                           cp.upstream_version,
+                repo.pristine_tar.checkout(source.name,
+                                           source.upstream_version,
                                            options.comp_type,
                                            output_dir,
                                            component=component)
@@ -289,7 +310,7 @@ def pristine_tar_build_orig(repo, cp, output_dir, options):
     return False
 
 
-def pristine_tar_verify_orig(repo, cp, options, output_dir, orig_files):
+def pristine_tar_verify_orig(repo, source, options, output_dir, orig_files):
     """
     Verify orig tarballs using prstine tar
 
@@ -298,23 +319,26 @@ def pristine_tar_verify_orig(repo, cp, options, output_dir, orig_files):
     if not options.pristine_tar:
         return True
 
-    pristine_tar_prepare_orig_tree(repo, cp, options)
+    pristine_tar_prepare_orig_tree(repo, source, options)
     for f in orig_files:
         repo.pristine_tar.verify(os.path.join(output_dir, f))
     return True
 
 
-def get_upstream_tree(repo, cp, options):
+def get_upstream_tree(repo, source, options):
     """Determine the upstream tree from the given options"""
     if options.upstream_tree.upper() == 'TAG':
-        if cp['Upstream-Version'] is None:
+        if source.upstream_version is None:
             raise GitRepositoryError("Can't determine upstream version from changelog")
         upstream_tree = repo.version_to_tag(options.upstream_tag,
-                                            cp['Upstream-Version'])
+                                            source.upstream_version)
     elif options.upstream_tree.upper() == 'BRANCH':
         if not repo.has_branch(options.upstream_branch):
             raise GbpError("%s is not a valid branch" % options.upstream_branch)
         upstream_tree = options.upstream_branch
+    elif options.upstream_tree.upper() == 'SLOPPY':
+        tree_name = "%s^{tree}" % options.debian_branch
+        upstream_tree = repo.tree_drop_dirs(tree_name, ["debian"])
     else:
         upstream_tree = options.upstream_tree
     if not repo.has_treeish(upstream_tree):
@@ -322,12 +346,12 @@ def get_upstream_tree(repo, cp, options):
     return upstream_tree
 
 
-def git_archive_build_orig(repo, cp, output_dir, options):
+def git_archive_build_orig(repo, source, output_dir, options):
     """
     Build orig tarball(s) using git-archive
 
-    @param cp: the changelog of the package we're acting on
-    @type cp: L{ChangeLog}
+    @param source: the changelog of the package we're acting on
+    @type source: L{DebianSource}
     @param output_dir: where to put the tarball
     @type output_dir: C{Str}
     @param options: the parsed options
@@ -335,8 +359,8 @@ def git_archive_build_orig(repo, cp, output_dir, options):
     @return: the tree we built the tarball from
     @rtype: C{str}
     """
-    upstream_tree = get_upstream_tree(repo, cp, options)
-    gbp.log.info("Creating %s from '%s'" % (du.orig_file(cp,
+    upstream_tree = get_upstream_tree(repo, source, options)
+    gbp.log.info("Creating %s from '%s'" % (du.orig_file(source,
                                                          options.comp_type),
                                             upstream_tree))
     comp_level = int(options.comp_level) if options.comp_level != '' else None
@@ -344,7 +368,7 @@ def git_archive_build_orig(repo, cp, output_dir, options):
                   (options.comp_type,
                    "' -%s'" % comp_level if comp_level is not None else ''))
     main_tree = repo.tree_drop_dirs(upstream_tree, options.components) if options.components else upstream_tree
-    if not git_archive(repo, cp, output_dir, main_tree,
+    if not git_archive(repo, source, output_dir, main_tree,
                        options.comp_type,
                        comp_level,
                        options.with_submodules):
@@ -355,9 +379,9 @@ def git_archive_build_orig(repo, cp, output_dir, options):
             raise GbpError("No tree for '%s' found in '%s' to create additional tarball from"
                            % (component, upstream_tree))
         gbp.log.info("Creating additional tarball '%s' from '%s'"
-                     % (du.orig_file(cp, options.comp_type, component=component),
+                     % (du.orig_file(source, options.comp_type, component=component),
                         subtree))
-        if not git_archive(repo, cp, output_dir, subtree,
+        if not git_archive(repo, source, output_dir, subtree,
                            options.comp_type,
                            comp_level,
                            options.with_submodules,
@@ -367,12 +391,8 @@ def git_archive_build_orig(repo, cp, output_dir, options):
     return upstream_tree
 
 
-def guess_comp_type(repo, comp_type, cp, tarball_dir):
+def guess_comp_type(repo, comp_type, source, tarball_dir):
     """Guess compression type"""
-
-    srcpkg = cp['Source']
-    upstream_version = cp['Upstream-Version']
-
     if comp_type != 'auto':
         comp_type = compressor_aliases.get(comp_type, comp_type)
         if comp_type not in compressor_opts:
@@ -385,7 +405,7 @@ def guess_comp_type(repo, comp_type, cp, tarball_dir):
                 tarball_dir = '..'
             detected = None
             for comp in compressor_opts.keys():
-                if du.DebianPkgPolicy.has_orig(du.orig_file(cp, comp), tarball_dir):
+                if du.DebianPkgPolicy.has_orig(du.orig_file(source, comp), tarball_dir):
                     if detected is not None:
                         raise GbpError("Multiple orig tarballs found.")
                     detected = comp
@@ -394,7 +414,7 @@ def guess_comp_type(repo, comp_type, cp, tarball_dir):
             else:
                 comp_type = 'gzip'
         else:
-            regex = 'pristine-tar .* %s_%s\.orig.tar\.' % (srcpkg, upstream_version)
+            regex = 'pristine-tar .* %s_%s\.orig.tar\.' % (source.name, source.upstream_version)
             commits = repo.grep_log(regex, repo.pristine_tar_branch)
             if commits:
                 commit = commits[-1]
@@ -412,7 +432,7 @@ def guess_comp_type(repo, comp_type, cp, tarball_dir):
 
 def check_tag(options, repo, source):
     """Perform specified consistency checks on git history"""
-    tag = repo.version_to_tag(options.debian_tag, source.changelog.version)
+    tag = repo.version_to_tag(options.debian_tag, source.version)
     if (options.tag or options.tag_only) and not options.retag:
         if repo.has_tag(tag):
             raise GbpError("Tag '%s' already exists" % tag)
@@ -486,6 +506,15 @@ def setup_pbuilder(options, repo, native):
     return pbd_env, hook_env
 
 
+def mangle_export_wc_opts(options):
+    """
+    Make building with --export=WC simpler
+    """
+    if options.export == wc_name:
+        options.ignore_branch = True
+        options.ignore_new = True
+
+
 def disable_hooks(options):
     """Disable all hooks (except for builder)"""
     for hook in ['cleaner', 'postexport', 'prebuild', 'postbuild', 'posttag']:
@@ -649,6 +678,7 @@ def parse_args(argv, prefix):
         gbp.log.warn("Components specified, pristine-tar-commit not yet supported - disabling it.")
         options.pristine_tar_commit = False
 
+    mangle_export_wc_opts(options)
     return options, args, dpkg_args
 
 
@@ -671,13 +701,7 @@ def main(argv):
         return 1
 
     try:
-        Command(options.cleaner, shell=True)()
-        if not options.ignore_new:
-            (ret, out) = repo.is_clean()
-            if not ret:
-                gbp.log.err("You have uncommitted changes in your source tree:")
-                gbp.log.err(out)
-                raise GbpError("Use --git-ignore-new to ignore.")
+        clean_working_tree(options, repo)
 
         try:
             branch = repo.get_branch()
@@ -692,7 +716,7 @@ def main(argv):
                 raise GbpError("Use --git-ignore-branch to ignore or --git-debian-branch to set the branch name.")
 
         head = repo.head
-        tree = write_tree(repo, options)
+        tree = maybe_write_tree(repo, options)
         source = source_vfs(repo, options, tree)
 
         check_tag(options, repo, source)
@@ -710,7 +734,7 @@ def main(argv):
                 if options.postexport:
                     gbp.log.info("Postexport hook set, delaying tarball creation")
                 else:
-                    prepare_upstream_tarball(repo, source.changelog, options, tarball_dir,
+                    prepare_upstream_tarball(repo, source, options, tarball_dir,
                                              output_dir)
 
             build_env, hook_env = setup_pbuilder(options, repo, source.is_native())
@@ -728,8 +752,8 @@ def main(argv):
                                             'GBP_TMP_DIR': tmp_dir})
                          )(dir=tmp_dir)
 
-                major = (source.changelog.debian_version if source.is_native()
-                         else source.changelog.upstream_version)
+                major = (source.debian_version if source.is_native()
+                         else source.upstream_version)
                 export_dir = os.path.join(output_dir, "%s-%s" % (source.sourcepkg, major))
                 gbp.log.info("Moving '%s' to '%s'" % (tmp_dir, export_dir))
                 move_old_export(export_dir)
@@ -737,7 +761,7 @@ def main(argv):
 
                 # Delayed tarball creation in case a postexport hook is used:
                 if not source.is_native() and options.postexport:
-                    prepare_upstream_tarball(repo, source.changelog, options, tarball_dir,
+                    prepare_upstream_tarball(repo, source, options, tarball_dir,
                                              output_dir)
                 build_dir = export_dir
             else:
@@ -760,7 +784,7 @@ def main(argv):
             if options.postbuild:
                 changes = os.path.abspath("%s/../%s_%s_%s.changes" %
                                           (build_dir,
-                                           source.sourcepkg,
+                                           source.changelog.name,
                                            source.changelog.noepoch,
                                            changes_file_suffix(dpkg_args)))
                 gbp.log.debug("Looking for changes file %s" % changes)
@@ -770,18 +794,24 @@ def main(argv):
                                         'GBP_BUILD_DIR': build_dir})
                      )()
         if options.tag or options.tag_only:
-            tag = repo.version_to_tag(options.debian_tag, source.changelog.version)
-            gbp.log.info("Tagging %s as %s" % (source.changelog.version, tag))
+            if branch and is_pq_branch(branch):
+                commit = repo.get_merge_base(branch, pq_branch_base(branch))
+            else:
+                commit = head
+
+            tag = repo.version_to_tag(options.debian_tag, source.version)
+            gbp.log.info("Tagging %s as %s" % (source.version, tag))
             if options.retag and repo.has_tag(tag):
                 repo.delete_tag(tag)
             tag_msg = format_str(options.debian_tag_msg,
                                  dict(pkg=source.sourcepkg,
-                                      version=source.changelog.version))
+                                      version=source.version))
             repo.create_tag(name=tag,
                             msg=tag_msg,
                             sign=options.sign_tags,
-                            commit=head,
+                            commit=commit,
                             keyid=options.keyid)
+
             if options.posttag:
                 sha = repo.rev_parse("%s^{}" % tag)
                 Hook('Posttag', options.posttag,
