@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2011,2014 Guido Günther <agx@sigxcpu.org>
+# (C) 2011,2014,2017 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -112,14 +112,14 @@ def compare_series(old, new):
     """
     Compare new pathes to lists of patches already exported
 
-    >>> compare_series(['a', 'b'], ['b', 'c'])
+    >>> compare_series(['# comment', 'a', 'b'], ['b', 'c'])
     (['c'], ['a'])
     >>> compare_series([], [])
     ([], [])
     """
     added = set(new).difference(old)
-    removed = set(old).difference(new)
-    return (list(added), list(removed))
+    removed = [l for l in set(old).difference(new) if not l.startswith('#')]
+    return (list(added), removed)
 
 
 def format_series_diff(added, removed, options):
@@ -223,18 +223,19 @@ def export_patches(repo, branch, options):
         with open(series_file, 'w') as seriesfd:
             for patch in patches:
                 seriesfd.write(os.path.relpath(patch, patch_dir) + '\n')
-        if options.commit:
-            added, removed = commit_patches(repo, branch, patches, options, patch_dir)
-            if added:
-                what = 'patches' if len(added) > 1 else 'patch'
-                gbp.log.info("Added %s %s to patch series" % (what, ', '.join(added)))
-            if removed:
-                what = 'patches' if len(removed) > 1 else 'patch'
-                gbp.log.info("Removed %s %s from patch series" % (what, ', '.join(removed)))
+    else:
+        gbp.log.info("No patches on '%s' - nothing to export." % pq_branch)
+
+    if options.commit:
+        added, removed = commit_patches(repo, branch, patches, options, patch_dir)
+        if added:
+            what = 'patches' if len(added) > 1 else 'patch'
+            gbp.log.info("Added %s %s to patch series" % (what, ', '.join(added)))
+        if removed:
+            what = 'patches' if len(removed) > 1 else 'patch'
+            gbp.log.info("Removed %s %s from patch series" % (what, ', '.join(removed)))
         else:
             GitCommand('status', cwd=repo.path)(['--', PATCH_DIR])
-    else:
-        gbp.log.info("No patches on '%s' - nothing to do." % pq_branch)
 
     if options.drop:
         drop_pq(repo, branch)
