@@ -19,6 +19,7 @@
 import hashlib
 import os
 import subprocess
+import tarfile
 
 from tests.component import (ComponentTestBase,
                              ComponentTestGitRepository)
@@ -29,6 +30,9 @@ from nose.tools import ok_, eq_, assert_false, assert_true
 
 from gbp.scripts.import_dsc import main as import_dsc
 from gbp.scripts.buildpackage import main as buildpackage
+from gbp.scripts.pq import main as pq
+
+from gbp.deb.changelog import ChangeLog
 
 
 class TestBuildpackage(ComponentTestBase):
@@ -137,15 +141,40 @@ class TestBuildpackage(ComponentTestBase):
         for t in tarballs:
             self.assertTrue(os.path.exists(t), "Tarball %s not found" % t)
 
+    @RepoFixtures.quilt30()
+    def test_sloppy_tarball_generation(self, repo):
+        """Test that generating tarball from Debian branch works"""
+        tarball = '../hello-debhelper_2.8.orig.tar.gz'
+        self.add_file(repo, 'foo.txt')
+        self._test_buildpackage(repo, ['--git-force-create',
+                                       '--git-upstream-tree=SLOPPY'])
+        self.assertTrue(os.path.exists(tarball))
+        t = tarfile.open(name=tarball, mode="r:gz")
+        names = t.getnames()
+        for f in ['hello-debhelper-2.8/build-aux',
+                  'hello-debhelper-2.8/foo.txt']:
+            self.assertIn(f, names)
+        self.assertNotIn('hello-debhelper-2.8/debian', names)
+
     @RepoFixtures.quilt30()
     def test_export_dir_buildpackage(self, repo):
         """Test that building with a export dir works"""
         self._test_buildpackage(repo, ['--git-export-dir=../foo/bar'])
         ok_(os.path.exists('../foo/bar'))
 
+    @RepoFixtures.quilt30()
+    def test_export_wc_buildpackage(self, repo):
+        """Test that exporting working copy works and it ignores
+        modifications the source tree """
+        with open(os.path.join(repo.path, 'foo.txt'), 'w') as f:
+            f.write("foo")
+        self._test_buildpackage(repo, ['--git-export=WC',
+                                       '--git-export-dir=../foo/bar'])
+        ok_(os.path.exists('../foo/bar'))
+
     @RepoFixtures.native()
     def test_argument_quoting(self, repo):
-        """Test that we quote arguments to builder (#)"""
+        """Test that we quote arguments to builder (#850869)"""
         with open('../arg with spaces', 'w'):
             pass
         # We use ls as builder to look for a file with spaces. This
@@ -174,9 +203,53 @@ class TestBuildpackage(ComponentTestBase):
         m2 = hashlib.md5(open(tarball, 'rb').read()).hexdigest()
         eq_(m1, m2, "Regenerated tarball has different checksum")
 
-    @RepoFixtures.quilt30
+    @RepoFixtures.quilt30()
     def test_tarball_max_compression(self, repo):
         """Test that passing max compression works (#820846)"""
         self._test_buildpackage(repo, ['--git-no-pristine-tar', '--git-compression-level=9'])
         out = subprocess.check_output(["file", "../hello-debhelper_2.8.orig.tar.gz"])
         ok_("max compression" in out)
+
+    @RepoFixtures.quilt30()
+    def test_tag_pq_branch(self, repo):
+        ret = pq(['argv0', 'import'])
+        eq_(repo.rev_parse('master'), repo.rev_parse('debian/2.8-1^{}'))
+        eq_(ret, 0)
+        eq_(repo.branch, 'patch-queue/master')
+        self.add_file(repo, 'foo.txt')
+        ret = buildpackage(['argv0',
+                            '--git-tag-only',
+                            '--git-retag',
+                            '--git-ignore-branch'])
+        eq_(ret, 0)
+        eq_(repo.branch, 'patch-queue/master')
+        eq_(repo.rev_parse('patch-queue/master^{}^'), repo.rev_parse('debian/2.8-1^{}'))
+
+    @RepoFixtures.quilt30()
+    def test_tag_detached_head(self, repo):
+        """
+        Test that tagging works with an detached head (#863167)
+        """
+        eq_(repo.rev_parse('master^{}'), repo.rev_parse('debian/2.8-1^{}'))
+        self.add_file(repo, 'debian/foo.txt')
+        repo.checkout("HEAD~")
+        ret = buildpackage(['argv0',
+                            '--git-tag-only',
+                            '--git-retag',
+                            '--git-ignore-branch'])
+        eq_(ret, 0)
+        repo.checkout("master")
+        eq_(repo.rev_parse('master~^{}'), repo.rev_parse('debian/2.8-1^{}'))
+
+    @RepoFixtures.quilt30()
+    def test_broken_upstream_version(self, repo):
+        cl = ChangeLog(filename='debian/changelog')
+        cl.add_section(["broken versionnumber"],
+                       "unstable",
+                       version={'version': "3.0"})
+        ret = buildpackage(['argv0',
+                            '--git-ignore-new',
+                            '--git-builder=/bin/true',
+                            '--git-tarball-dir=../tarballs'])
+        eq_(ret, 1)
+        self._check_log(-1, "gbp:error: Non-native package 'hello-debhelper' has invalid version '3.0'")
