@@ -19,7 +19,8 @@
 import os
 
 from tests.component import (ComponentTestBase,
-                             ComponentTestGitRepository)
+                             ComponentTestGitRepository,
+                             skipUnless)
 from tests.component.deb.fixtures import RepoFixtures
 
 from nose.tools import ok_
@@ -55,16 +56,29 @@ class TestClone(ComponentTestBase):
         assert len(cloned.get_commits()) == 1
         self.check_hook_vars('postclone', ["GBP_GIT_DIR"])
 
-    def test_clone_environ(self):
-        """Test that environment variables influence git configuration"""
-        # Build up somethng we can clone from
-        os.environ['DEBFULLNAME'] = 'testing tester'
-        os.environ['DEBEMAIL'] = 'gbp-tester@debian.invalid'
-        repo = RepoFixtures.import_native()
-        got = repo.get_config("user.email")
-        want = os.environ['DEBEMAIL']
-        ok_(got == want, "unexpected git config user.email: got %s, want %s" % (got, want))
+    @skipUnless(os.getenv("GBP_NETWORK_TESTS"), "network tests disabled")
+    def test_clone_vcsgit_ok(self):
+        """Test that cloning from vcs-git urls works"""
+        dest = os.path.join(self._tmpdir,
+                            'cloned_repo')
+        ret = clone(['arg0', "vcsgit:libvirt-glib", dest])
+        self.assertEquals(ret, 0)
+        cloned = ComponentTestGitRepository(dest)
+        self._check_repo_state(cloned, 'debian/sid', ['debian/sid', 'upstream/latest'])
 
-        got = repo.get_config("user.name")
-        want = os.environ['DEBFULLNAME']
-        ok_(got == want, "unexpected git config user.name: got %s, want %s" % (got, want))
+    @skipUnless(os.getenv("GBP_NETWORK_TESTS"), "network tests disabled")
+    def test_clone_vcsgit_fail(self):
+        """Test that cloning from vcs-git urls fails as expected"""
+        ret = clone(['arg0', "vcsgit:doesnotexist"])
+        self.assertEquals(ret, 1)
+        self._check_log(-1, "gbp:error: Can't find a source package for 'doesnotexist'")
+
+    @skipUnless(os.getenv("GBP_NETWORK_TESTS"), "network tests disabled")
+    def test_clone_github(self):
+        """Test that cloning from github urls works"""
+        dest = os.path.join(self._tmpdir,
+                            'cloned_repo')
+        ret = clone(['arg0', "github:agx/git-buildpackage", dest])
+        self.assertEquals(ret, 0)
+        cloned = ComponentTestGitRepository(dest)
+        self._check_repo_state(cloned, 'master', ['master'])
