@@ -22,6 +22,7 @@ from tests.component import (ComponentTestBase,
                              ComponentTestGitRepository,
                              skipUnless)
 from tests.component.deb import DEB_TEST_DATA_DIR, DEB_TEST_DOWNLOAD_URL
+from tests.component.deb.fixtures import RepoFixtures
 
 from nose.tools import ok_, eq_
 
@@ -33,6 +34,22 @@ from gbp.deb.dscfile import DscFile
 class TestImportDsc(ComponentTestBase):
     """Test importing of debian source packages"""
 
+    def _check_reflog(self, repo):
+        reflog, ret = repo._git_getoutput('reflog')
+        # Recent (>= 2.10) git versions create a reflog entry for "git
+        # update-ref HEAD HEAD" while older ones (2.9.4) don't so
+        # reflog[0] is either there or not.
+        if len(reflog) == 3:
+            ok_("gbp: Import Debian changes" in reflog[1])
+            ok_("gbp: Import Upstream version 2.6" in reflog[2])
+        elif len(reflog) == 2:
+            # Furthermore some older git versions (<2.10) fail to set
+            # the reflog correctly on the initial commit so only check
+            # the second
+            ok_("gbp: Import Debian changes" in reflog[0])
+        else:
+            assert ok_(len(reflog) in [2, 3])
+
     def test_import_debian_native(self):
         """Test that importing of debian native packages works"""
         def _dsc(version):
@@ -111,9 +128,7 @@ class TestImportDsc(ComponentTestBase):
         repo = ComponentTestGitRepository('hello-debhelper')
         os.chdir('hello-debhelper')
         assert len(repo.get_commits()) == 2
-        reflog, ret = repo._git_getoutput('reflog')
-        ok_("gbp: Import Debian changes" in reflog[1])
-        ok_("gbp: Import Upstream version 2.6" in reflog[2])
+        self._check_reflog(repo)
         self._check_repo_state(repo, 'master', ['master', 'pristine-tar', 'upstream'])
         dsc = _dsc('2.8-1')
         assert import_dsc(['arg0',
@@ -238,9 +253,7 @@ class TestImportDsc(ComponentTestBase):
         repo = ComponentTestGitRepository('hello-debhelper')
         os.chdir('hello-debhelper')
         assert len(repo.get_commits()) == 2
-        reflog, ret = repo._git_getoutput('reflog')
-        ok_("gbp: Import Debian changes" in reflog[1])
-        ok_("gbp: Import Upstream version 2.6" in reflog[2])
+        self._check_reflog(repo)
         self._check_repo_state(repo, 'master', ['master', 'pristine-tar', 'upstream'])
         commitmsg = repo.get_commit_info('HEAD')['body']
         ok_("hello-debhelper (2.6-2) unstable; urgency=medium" in commitmsg)
@@ -259,3 +272,16 @@ class TestImportDsc(ComponentTestBase):
         ok_("hello-debhelper (2.8-1) unstable; urgency=low" in commitmsg)
         ok_("ello-debhelper (2.7-1) unstable; urgency=low" in commitmsg)
         ok_("hello-debhelper (2.6-2) unstable; urgency=medium" not in commitmsg)
+
+    def test_import_environ(self):
+        """Test that environment variables influence git configuration"""
+        os.environ['DEBFULLNAME'] = 'testing tester'
+        os.environ['DEBEMAIL'] = 'gbp-tester@debian.invalid'
+        repo = RepoFixtures.import_native()
+        got = repo.get_config("user.email")
+        want = os.environ['DEBEMAIL']
+        ok_(got == want, "unexpected git config user.email: got %s, want %s" % (got, want))
+
+        got = repo.get_config("user.name")
+        want = os.environ['DEBFULLNAME']
+        ok_(got == want, "unexpected git config user.name: got %s, want %s" % (got, want))
