@@ -101,8 +101,8 @@ def test_add_files():
 
     >>> import gbp.git, shutil, os
     >>> repo = gbp.git.GitRepository(dirs['repo'])
-    >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"),
-    ...                                os.path.join(repo.path, "testfile"))
+    >>> shutil.copy(os.path.join(repo.path, ".git/HEAD"),
+    ...                          os.path.join(repo.path, "testfile"))
     >>> repo.is_clean()[0]
     False
     >>> repo.is_clean('doesnotexist')[0]
@@ -123,6 +123,22 @@ def test_add_files():
     """
 
 
+def test_move_file():
+    """
+    Methods tested:
+         - L{gbp.git.GitRepository.move_file}
+
+    >>> import gbp.git
+    >>> repo = gbp.git.GitRepository(dirs['repo'])
+    >>> repo.rename_file("testfile", "testfile2")
+    >>> repo.rename_file("testfile2", "testfile")
+    >>> repo.rename_file("doesnotexit", "testfile2")
+    Traceback (most recent call last):
+    ...
+    GbpError: Failed to move 'doesnotexit' to 'testfile2': fatal: bad source, source=doesnotexit, destination=testfile2
+    """
+
+
 def test_branch_master():
     """
     First branch is called I{master}
@@ -654,7 +670,7 @@ def test_clone():
 
 def test_get_remotes():
     """
-    Merge a branch
+    Check remotes
 
     Methods tested:
          - L{gbp.git.GitRepository.get_remotes}
@@ -687,6 +703,8 @@ def test_merge():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch('master')
     >>> repo.merge('foo')
+    >>> repo.is_in_merge()
+    False
     """
 
 
@@ -1037,6 +1055,20 @@ def test_set_user_name_and_email():
     """
 
 
+def test_set_config_and_get_config():
+    r"""
+    Methods tested:
+        - L{gbp.git.GitRepository.set_config}
+        - L{gbp.git.GitRepository.get_config}
+
+    >>> import gbp.git
+    >>> repo = gbp.git.GitRepository(dirs['repo'])
+    >>> repo.set_config("user.email", "foo@example.com")
+    >>> repo.get_config("user.email")
+    'foo@example.com'
+    """
+
+
 def test_git_dir():
     """
     Properties tested:
